<?php
/**
 * Created by PhpStorm.
 * User: FrédéricGuichard
 * Date: 21/09/2016
 * Time: 17:11
 */

namespace ByDedi\AdminBundle\Form\Type;

use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\Form\FormInterface;
use Symfony\Component\Form\FormView;
use Symfony\Component\OptionsResolver\OptionsResolver;

/**
 * Class CollectionType
 * @package ByDedi\AdminBundle\Form\Type
 */
class CollectionType extends \Sonata\CoreBundle\Form\Type\CollectionType
{
    /**
     * {@inheritdoc}
     */
    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        if (!empty($options['hide_table'])) {
            $builder->setData(null);
            $builder->setAutoInitialize(false);
            $builder->setDisabled(true);
        }
        parent::buildForm($builder, $options);
    }

    /**
     * @param OptionsResolver $resolver
     */
    public function configureOptions(OptionsResolver $resolver)
    {
        parent::configureOptions($resolver);
        $resolver->setDefaults([
            'by_reference' => false,
            'visible_fields' => [],
            'hidden_fields' => [],
            'label_render' => false,
            'label' => false,
            'read_only_table' => false,
            'hide_table' => false,
            'btn_list' => true,
            'list_url' => null,
            'action_list' => true,
            'associated_admin' => null,
            'associated_admin_property' => null,
            'edition_type' => 'inline',
            'edition_type_inline' => 'table'
        ]);
    }

    /**
     * @param FormView $view
     * @param FormInterface $form
     * @param array $options
     */
    public function buildView(FormView $view, FormInterface $form, array $options)
    {
        parent::buildView($view, $form, $options);
        $view->vars['visible_fields'] = $options['visible_fields'];
        $view->vars['hidden_fields'] = $options['hidden_fields'];
        $view->vars['read_only_table'] = $options['read_only_table'];
        $view->vars['action_list'] = $options['action_list'];
        $view->vars['btn_list'] = $options['btn_list'];
        $view->vars['hide_table'] = $options['hide_table'];
        $view->vars['associated_admin'] = $options['associated_admin'];
        $view->vars['associated_admin_property'] = $options['associated_admin_property'];

        $view->vars['sonata_admin']['edit'] = $options['edition_type'];
        $view->vars['sonata_admin']['inline'] = $options['edition_type_inline'];

        $code = "code=".$view->vars['sonata_admin']['field_description']->getAssociationAdmin()->getCode();
        $origineId = "origin_id=".$view->vars['sonata_admin']['admin']->getSubject()->getId();
        $pcode = "pcode=".$view->vars['sonata_admin']['admin']->getCode();
        $puniqid = "puniqid=".$view->vars['sonata_admin']['admin']->getUniqId();

        $view->vars['list_url'] = $options['list_url'];

        if ($options['list_url'] != null) {
            $view->vars['list_url'].= "?".$code."&".$origineId."&".$pcode."&".$puniqid;
        }

        if ($options['associated_admin'] != null && $options['associated_admin_property'] != null) {
            $view->vars['associated_admin'] = $options['associated_admin'];
            $view->vars['associated_admin_property'] = $options['associated_admin_property'];
            $view->vars['url_parameters'] = "?".$code."&".$origineId."&".$pcode."&".$puniqid;
        }
    }
}
